changeset 12152:64131ac8b004

relocatable: prefer 'file system' over 'filesystem' * m4/relocatable-lib.m4 (gl_RELOCATABLE_NOP): Use AS_HELP_STRING. (gl_RELOCATABLE_LIBRARY_BODY): Fix spelling. * doc/relocatable-maint.texi (Supporting Relocation): Likewise. * doc/relocatable.texi (Enabling Relocatability): Likewise. * lib/relocatable.c (compute_curr_prefix): Likewise. Signed-off-by: Eric Blake <ebb9@byu.net>
author Eric Blake <ebb9@byu.net>
date Fri, 09 Oct 2009 19:17:38 -0600
parents a7584cfe3c46
children 4443f8be082f
files ChangeLog doc/relocatable-maint.texi doc/relocatable.texi lib/relocatable.c m4/relocatable-lib.m4
diffstat 5 files changed, 20 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2009-10-10  Eric Blake  <ebb9@byu.net>
+
+	relocatable: prefer 'file system' over 'filesystem'
+	* m4/relocatable-lib.m4 (gl_RELOCATABLE_NOP): Use AS_HELP_STRING.
+	(gl_RELOCATABLE_LIBRARY_BODY): Fix spelling.
+	* doc/relocatable-maint.texi (Supporting Relocation): Likewise.
+	* doc/relocatable.texi (Enabling Relocatability): Likewise.
+	* lib/relocatable.c (compute_curr_prefix): Likewise.
+
 2009-10-10  Jim Meyering  <meyering@redhat.com>
 
 	stat-time-tests: check for the usleep function
--- a/doc/relocatable-maint.texi
+++ b/doc/relocatable-maint.texi
@@ -15,7 +15,7 @@
 different versions of the same binary package.
 
 A relocatable program can be moved or copied to a different location
-on the filesystem.  It is possible to make symlinks to the installed
+on the file system.  It is possible to make symlinks to the installed
 and moved programs, and invoke them through the symlink. It is
 possible to do the same thing with a hard link @emph{only} if the hard
 link file is in the same directory as the real program.
--- a/doc/relocatable.texi
+++ b/doc/relocatable.texi
@@ -15,7 +15,7 @@
 different versions of the same binary package.
 
 A relocatable program can be moved or copied to a different location
-on the filesystem.  It is possible to make symlinks to the installed
+on the file system.  It is possible to make symlinks to the installed
 and moved programs, and invoke them through the symlink. It is
 possible to do the same thing with a hard link @emph{only} if the hard
 link file is in the same directory as the real program.
--- a/m4/relocatable-lib.m4
+++ b/m4/relocatable-lib.m4
@@ -1,4 +1,4 @@
-# relocatable-lib.m4 serial 4
+# relocatable-lib.m4 serial 5
 dnl Copyright (C) 2003, 2005-2007, 2009 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -27,7 +27,8 @@
     [Define to the value of ${prefix}, as a string.])
   if test $RELOCATABLE = yes; then
     AC_DEFINE([ENABLE_RELOCATABLE], [1],
-      [Define to 1 if the package shall run at any location in the filesystem.])
+      [Define to 1 if the package shall run at any location in the file
+       system.])
   fi
 ])
 
@@ -43,7 +44,8 @@
 [
   AC_MSG_CHECKING([whether to activate relocatable installation])
   AC_ARG_ENABLE([relocatable],
-    [  --enable-relocatable    install a package that can be moved in the filesystem],
+    [AS_HELP_STRING([--enable-relocatable],
+      [install a package that can be moved in the file system])],
     [if test "$enableval" != no; then
        RELOCATABLE=yes
      else
--- a/lib/relocatable.c
+++ b/lib/relocatable.c
@@ -1,5 +1,5 @@
 /* Provide relocatable packages.
-   Copyright (C) 2003-2006, 2008 Free Software Foundation, Inc.
+   Copyright (C) 2003-2006, 2008-2009 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2003.
 
    This program is free software; you can redistribute it and/or modify it
@@ -233,11 +233,11 @@
 		  same = true;
 		break;
 	      }
 	    /* Do case-insensitive comparison if the filesystem is always or
 	       often case-insensitive.  It's better to accept the comparison
 	       if the difference is only in case, rather than to fail.  */
 #if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__ || defined __EMX__ || defined __DJGPP__
 	    /* Win32, Cygwin, OS/2, DOS - case insignificant filesystem */
 	    if ((*rpi >= 'a' && *rpi <= 'z' ? *rpi - 'a' + 'A' : *rpi)
 		!= (*cpi >= 'a' && *cpi <= 'z' ? *cpi - 'a' + 'A' : *cpi))
 	      break;
@@ -450,7 +450,7 @@
 #endif
 
   /* Note: It is not necessary to perform case insensitive comparison here,
-     even for DOS-like filesystems, because the pathname argument was
+     even for DOS-like file systems, because the pathname argument was
      typically created from the same Makefile variable as orig_prefix came
      from.  */
   if (orig_prefix != NULL && curr_prefix != NULL
@@ -233,11 +233,11 @@
 		break;
 	      }
-	    /* Do case-insensitive comparison if the filesystem is always or
+	    /* Do case-insensitive comparison if the file system is always or
 	       often case-insensitive.  It's better to accept the comparison
 	       if the difference is only in case, rather than to fail.  */
@@ -233,11 +233,11 @@
 	       if the difference is only in case, rather than to fail.  */
 #if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__ || defined __EMX__ || defined __DJGPP__
-	    /* Win32, Cygwin, OS/2, DOS - case insignificant filesystem */
+	    /* Win32, Cygwin, OS/2, DOS - case insignificant file system */
 	    if ((*rpi >= 'a' && *rpi <= 'z' ? *rpi - 'a' + 'A' : *rpi)
 		!= (*cpi >= 'a' && *cpi <= 'z' ? *cpi - 'a' + 'A' : *cpi))